import React from 'react';
import { Input } from 'antd';
import IconFont from '../../extra/iconFont';
import styles from './styles.less';
import { ApolloLinkProps } from '../editInterface';
import CellContainer from '../container';

const ApolloLink = (props: ApolloLinkProps) => {
    const { onChange, value } = props;
    const changeText = (i, e) => {
        const newValue = (value && value.slice()) || [];
        newValue[i].text = e.target.value;
        changeData(newValue);
    };
    const changeValue = (i, e) => {
        const newValue = (value && value.slice()) || [];
        newValue[i].value = e.target.value;
        changeData(newValue);
    };
    const addLink = () => {
        const newValue = (value && value.slice()) || [];
        newValue.push({ text: '', value: '' });
        changeData(newValue);
    };
    const delLink = (i) => {
        let newValue = (value && value.slice()) || [];
        newValue.splice(i, 1);
        changeData(newValue);
    };

    const changeData = (value) => {
        if (typeof onChange === 'function') {
            onChange(value);
        }
    };

    return (
        <div className={styles.container}>
            {value &&
                value.map((link, i) => {
                    return (
                        <div key={i} className={styles.content}>
                            <div className={styles.row}>
                                <span className={styles.label}>显示文字：</span>
                                <Input className={styles.input} value={link.text} onChange={changeText.bind(null, i)} />
                            </div>
                            <div className={styles.row}>
                                <span className={styles.label}>链接地址：</span>
                                <Input
                                    className={styles.input}
                                    value={link.value}
                                    onChange={changeValue.bind(null, i)}
                                />
                                <div className={styles.delContainer} onClick={delLink.bind(null, i)}>
                                    <IconFont className={styles.del} type="iconshanchu" />
                                </div>
                            </div>
                        </div>
                    );
                })}
            <div className={styles.btn} onClick={addLink}>
                <IconFont className={styles.icon} type="iconxinzeng" />
            </div>
        </div>
    );
};
export default CellContainer(ApolloLink);
